@@ -3,6 +3,7 @@ package gomplate
 import (
 	"fmt"
 	"io"
+	"maps"
 	"net/http"
 	"os"
 	"slices"
@@ -111,7 +112,7 @@ type rawConfig struct {
 
 // TODO: remove when we remove the deprecated array format for templates
 //
-// Deprecated: custom unmarshaling will be removed in the next version
+// Deprecated: custom unmarshalling will be removed in the next version
 func (c *Config) UnmarshalYAML(value *yaml.Node) error {
 	r := rawConfig{}
 	err := value.Decode(&r)
@@ -147,8 +148,8 @@ func (c *Config) UnmarshalYAML(value *yaml.Node) error {
 
 // TODO: remove when we remove the deprecated array format for templates
 //
-// Deprecated: custom unmarshaling will be removed in the next version
-func (c Config) MarshalYAML() (interface{}, error) {
+// Deprecated: custom unmarshalling will be removed in the next version
+func (c Config) MarshalYAML() (any, error) {
 	aux := rawConfig{
 		DataSources:           c.DataSources,
 		Context:               c.Context,
@@ -196,9 +197,7 @@ func mergeDataSources(left, right DataSource) DataSource {
 	if left.Header == nil {
 		left.Header = right.Header
 	} else {
-		for k, v := range right.Header {
-			left.Header[k] = v
-		}
+		maps.Copy(left.Header, right.Header)
 	}
 	return left
 }
@@ -325,9 +324,7 @@ func (c *Config) MergeFrom(o *Config) *Config {
 		c.Context = mergeDataSourceMaps(c.Context, o.Context)
 	}
 	if len(o.Plugins) > 0 {
-		for k, v := range o.Plugins {
-			c.Plugins[k] = v
-		}
+		maps.Copy(c.Plugins, o.Plugins)
 	}
 
 	return c
@@ -393,7 +390,7 @@ func (c Config) validate() (err error) {
 	return err
 }
 
-func notTogether(names []string, values ...interface{}) error {
+func notTogether(names []string, values ...any) error {
 	found := ""
 	for i, value := range values {
 		if isZero(value) {
@@ -408,7 +405,7 @@ func notTogether(names []string, values ...interface{}) error {
 	return nil
 }
 
-func mustTogether(left, right string, lValue, rValue interface{}) error {
+func mustTogether(left, right string, lValue, rValue any) error {
 	if !isZero(lValue) && isZero(rValue) {
 		return fmt.Errorf("these options must be set together: '%s', '%s'",
 			left, right)
@@ -417,7 +414,7 @@ func mustTogether(left, right string, lValue, rValue interface{}) error {
 	return nil
 }
 
-func isZero(value interface{}) bool {
+func isZero(value any) bool {
 	switch v := value.(type) {
 	case string:
 		return v == ""
