@@ -8,11 +8,11 @@ import (
 )
 
 // CreateBase64Funcs -
-func CreateBase64Funcs(ctx context.Context) map[string]interface{} {
-	f := map[string]interface{}{}
+func CreateBase64Funcs(ctx context.Context) map[string]any {
+	f := map[string]any{}
 
 	ns := &Base64Funcs{ctx}
-	f["base64"] = func() interface{} { return ns }
+	f["base64"] = func() any { return ns }
 
 	return f
 }
@@ -23,19 +23,19 @@ type Base64Funcs struct {
 }
 
 // Encode -
-func (Base64Funcs) Encode(in interface{}) (string, error) {
+func (Base64Funcs) Encode(in any) (string, error) {
 	b := toBytes(in)
 	return base64.Encode(b)
 }
 
 // Decode -
-func (Base64Funcs) Decode(in interface{}) (string, error) {
+func (Base64Funcs) Decode(in any) (string, error) {
 	out, err := base64.Decode(conv.ToString(in))
 	return string(out), err
 }
 
 // DecodeBytes -
-func (Base64Funcs) DecodeBytes(in interface{}) ([]byte, error) {
+func (Base64Funcs) DecodeBytes(in any) ([]byte, error) {
 	out, err := base64.Decode(conv.ToString(in))
 	return out, err
 }
@@ -44,7 +44,7 @@ type byter interface {
 	Bytes() []byte
 }
 
-func toBytes(in interface{}) []byte {
+func toBytes(in any) []byte {
 	if in == nil {
 		return []byte{}
 	}
