@@ -12,14 +12,14 @@ import (
 func TestCreateEnvFuncs(t *testing.T) {
 	t.Parallel()
 
-	for i := 0; i < 10; i++ {
+	for i := range 10 {
 		// Run this a bunch to catch race conditions
 		t.Run(strconv.Itoa(i), func(t *testing.T) {
 			t.Parallel()
 
 			ctx := context.Background()
 			fmap := CreateEnvFuncs(ctx)
-			actual := fmap["env"].(func() interface{})
+			actual := fmap["env"].(func() any)
 
 			assert.Equal(t, ctx, actual().(*EnvFuncs).ctx)
 		})
