@@ -8,13 +8,13 @@ import (
 )
 
 // CreateGCPFuncs -
-func CreateGCPFuncs(ctx context.Context) map[string]interface{} {
+func CreateGCPFuncs(ctx context.Context) map[string]any {
 	ns := &GcpFuncs{
 		ctx:     ctx,
 		gcpopts: gcp.GetClientOptions(),
 	}
-	return map[string]interface{}{
-		"gcp": func() interface{} { return ns },
+	return map[string]any{
+		"gcp": func() any { return ns },
 	}
 }
 
@@ -28,7 +28,7 @@ type GcpFuncs struct {
 
 // Meta -
 func (a *GcpFuncs) Meta(key string, def ...string) (string, error) {
-	a.meta = sync.OnceValue[*gcp.MetaClient](func() *gcp.MetaClient {
+	a.meta = sync.OnceValue(func() *gcp.MetaClient {
 		return gcp.NewMetaClient(a.ctx, a.gcpopts)
 	})()
 
