@@ -8,10 +8,10 @@ import (
 )
 
 // CreatePathFuncs -
-func CreatePathFuncs(ctx context.Context) map[string]interface{} {
+func CreatePathFuncs(ctx context.Context) map[string]any {
 	ns := &PathFuncs{ctx}
-	return map[string]interface{}{
-		"path": func() interface{} { return ns },
+	return map[string]any{
+		"path": func() any { return ns },
 	}
 }
 
@@ -21,43 +21,43 @@ type PathFuncs struct {
 }
 
 // Base -
-func (PathFuncs) Base(in interface{}) string {
+func (PathFuncs) Base(in any) string {
 	return path.Base(conv.ToString(in))
 }
 
 // Clean -
-func (PathFuncs) Clean(in interface{}) string {
+func (PathFuncs) Clean(in any) string {
 	return path.Clean(conv.ToString(in))
 }
 
 // Dir -
-func (PathFuncs) Dir(in interface{}) string {
+func (PathFuncs) Dir(in any) string {
 	return path.Dir(conv.ToString(in))
 }
 
 // Ext -
-func (PathFuncs) Ext(in interface{}) string {
+func (PathFuncs) Ext(in any) string {
 	return path.Ext(conv.ToString(in))
 }
 
 // IsAbs -
-func (PathFuncs) IsAbs(in interface{}) bool {
+func (PathFuncs) IsAbs(in any) bool {
 	return path.IsAbs(conv.ToString(in))
 }
 
 // Join -
-func (PathFuncs) Join(elem ...interface{}) string {
+func (PathFuncs) Join(elem ...any) string {
 	s := conv.ToStrings(elem...)
 	return path.Join(s...)
 }
 
 // Match -
-func (PathFuncs) Match(pattern, name interface{}) (matched bool, err error) {
+func (PathFuncs) Match(pattern, name any) (matched bool, err error) {
 	return path.Match(conv.ToString(pattern), conv.ToString(name))
 }
 
 // Split -
-func (PathFuncs) Split(in interface{}) []string {
+func (PathFuncs) Split(in any) []string {
 	dir, file := path.Split(conv.ToString(in))
 	return []string{dir, file}
 }
