@@ -4,20 +4,21 @@ import (
 	"testing"
 
 	"github.com/stretchr/testify/assert"
+	"github.com/stretchr/testify/require"
 )
 
 func TestFind(t *testing.T) {
 	f, err := Find(`[a-z]+`, `foo bar baz`)
-	assert.NoError(t, err)
+	require.NoError(t, err)
 	assert.Equal(t, "foo", f)
 
 	_, err = Find(`[a-`, "")
-	assert.Error(t, err)
+	require.Error(t, err)
 }
 
 func TestFindAll(t *testing.T) {
 	_, err := FindAll(`[a-`, 42, "")
-	assert.Error(t, err)
+	require.Error(t, err)
 
 	testdata := []struct {
 		re       string
@@ -33,16 +34,27 @@ func TestFindAll(t *testing.T) {
 
 	for _, d := range testdata {
 		f, err := FindAll(d.re, d.n, d.in)
-		assert.NoError(t, err)
+		require.NoError(t, err)
 		assert.EqualValues(t, d.expected, f)
 	}
 }
 
 func TestMatch(t *testing.T) {
-	assert.True(t, Match(`^[a-z]+\[[0-9]+\]$`, "adam[23]"))
-	assert.True(t, Match(`^[a-z]+\[[0-9]+\]$`, "eve[7]"))
-	assert.False(t, Match(`^[a-z]+\[[0-9]+\]$`, "Job[48]"))
-	assert.False(t, Match(`^[a-z]+\[[0-9]+\]$`, "snakey"))
+	actual, err := Match(`^[a-z]+\[[0-9]+\]$`, "adam[23]")
+	require.NoError(t, err)
+	assert.True(t, actual)
+
+	actual, err = Match(`^[a-z]+\[[0-9]+\]$`, "eve[7]")
+	require.NoError(t, err)
+	assert.True(t, actual)
+
+	actual, err = Match(`^[a-z]+\[[0-9]+\]$`, "Job[48]")
+	require.NoError(t, err)
+	assert.False(t, actual)
+
+	actual, err = Match(`^[a-z]+\[[0-9]+\]$`, "snakey")
+	require.NoError(t, err)
+	assert.False(t, actual)
 }
 
 func TestReplace(t *testing.T) {
@@ -59,13 +71,15 @@ func TestReplace(t *testing.T) {
 		{"Turing, Alan", "(?P<first>[a-zA-Z]+) (?P<last>[a-zA-Z]+)", "${last}, ${first}", "Alan Turing"},
 	}
 	for _, d := range testdata {
-		assert.Equal(t, d.expected, Replace(d.expression, d.replacement, d.input))
+		actual, err := Replace(d.expression, d.replacement, d.input)
+		require.NoError(t, err)
+		assert.Equal(t, d.expected, actual)
 	}
 }
 
 func TestReplaceLiteral(t *testing.T) {
 	_, err := ReplaceLiteral(`[a-`, "", "")
-	assert.Error(t, err)
+	require.Error(t, err)
 
 	testdata := []struct {
 		expected    string
@@ -81,14 +95,14 @@ func TestReplaceLiteral(t *testing.T) {
 	}
 	for _, d := range testdata {
 		r, err := ReplaceLiteral(d.expression, d.replacement, d.input)
-		assert.NoError(t, err)
+		require.NoError(t, err)
 		assert.Equal(t, d.expected, r)
 	}
 }
 
 func TestSplit(t *testing.T) {
 	_, err := Split(`[a-`, 42, "")
-	assert.Error(t, err)
+	require.Error(t, err)
 
 	testdata := []struct {
 		re       string
@@ -104,7 +118,7 @@ func TestSplit(t *testing.T) {
 
 	for _, d := range testdata {
 		f, err := Split(d.re, d.n, d.in)
-		assert.NoError(t, err)
+		require.NoError(t, err)
 		assert.EqualValues(t, d.expected, f)
 	}
 }
