@@ -4,48 +4,49 @@ import (
 	"testing"
 
 	"github.com/stretchr/testify/assert"
+	"github.com/stretchr/testify/require"
 )
 
 func TestAssert(t *testing.T) {
 	_, err := Assert(false, "")
-	assert.Error(t, err)
+	require.Error(t, err)
 	_, err = Assert(false, "a message")
-	assert.EqualError(t, err, "assertion failed: a message")
+	require.EqualError(t, err, "assertion failed: a message")
 
 	_, err = Assert(true, "")
-	assert.NoError(t, err)
+	require.NoError(t, err)
 }
 
 func TestFail(t *testing.T) {
 	err := Fail("")
-	assert.Error(t, err)
+	require.Error(t, err)
 	err = Fail("msg")
-	assert.EqualError(t, err, "template generation failed: msg")
+	require.EqualError(t, err, "template generation failed: msg")
 }
 
 func TestRequired(t *testing.T) {
 	v, err := Required("", nil)
-	assert.Error(t, err)
+	require.Error(t, err)
 	assert.Nil(t, v)
 
 	v, err = Required("", "")
-	assert.Error(t, err)
+	require.Error(t, err)
 	assert.Nil(t, v)
 
 	v, err = Required("foo", "")
-	assert.Error(t, err)
-	assert.EqualError(t, err, "foo")
+	require.Error(t, err)
+	require.EqualError(t, err, "foo")
 	assert.Nil(t, v)
 
 	v, err = Required("", 0)
-	assert.NoError(t, err)
-	assert.Equal(t, v, 0)
+	require.NoError(t, err)
+	assert.Zero(t, v)
 
 	v, err = Required("", false)
-	assert.NoError(t, err)
-	assert.Equal(t, v, false)
+	require.NoError(t, err)
+	assert.Equal(t, false, v)
 
 	v, err = Required("", map[string]string{})
-	assert.NoError(t, err)
+	require.NoError(t, err)
 	assert.NotNil(t, v)
 }
